package com.jiuqi.util;

import java.text.FieldPosition;
import com.jiuqi.util.chinese.ChineseInt;
import com.jiuqi.util.chinese.NoValidCharException;
import com.jiuqi.util.chinese.NotValidChineseNumberException;
import com.jiuqi.util.chinese.ChineseDouble;
import java.text.ParsePosition;
import java.text.NumberFormat;

public class ChineseNumberFormat extends NumberFormat
{
    private boolean useCapital;
    private int decimal;
    private static String[] chDigitUnits;
    
    static {
        ChineseNumberFormat.chDigitUnits = new String[] { "", "十", "百", "千", "万", "十万", "百万", "千万", "亿", "十亿", "百亿", "千亿", "万亿", "兆" };
    }
    
    public ChineseNumberFormat() {
        this.useCapital = false;
        this.decimal = 2;
    }
    
    public ChineseNumberFormat(final boolean useCapital) {
        this.useCapital = useCapital;
        this.decimal = 2;
    }
    
    public ChineseNumberFormat(final boolean useCapital, final int decimal) {
        this.useCapital = useCapital;
        this.decimal = decimal;
    }
    
    public boolean getUseCapital() {
        return this.useCapital;
    }
    
    public void setUseCapital(final boolean value) {
        this.useCapital = value;
    }
    
    public int getDecimal() {
        return this.decimal;
    }
    
    public void setDecimal(final int value) {
        this.decimal = value;
    }
    
    @Override
    public Number parse(final String source, final ParsePosition parsePosition) {
        if (source == null) {
            return null;
        }
        Label_0052: {
            if (source.indexOf("点") == -1) {
                if (source.indexOf("分之") == -1) {
                    break Label_0052;
                }
            }
            try {
                return new Double(ChineseDouble.valueOf(source));
            }
            catch (final NotValidChineseNumberException e) {
                e.printStackTrace();
                return null;
            }
            catch (final NoValidCharException e2) {
                e2.printStackTrace();
                return null;
            }
            try {
                return new Long(ChineseInt.valueOf(source));
            }
            catch (final NotValidChineseNumberException e) {
                e.printStackTrace();
                return null;
            }
            catch (final NoValidCharException e2) {
                e2.printStackTrace();
                return null;
            }
        }
    }
    
    @Override
    public StringBuffer format(final double number, final StringBuffer toAppendTo, final FieldPosition pos) {
        final String value = ChineseDouble.parseToChinese(String.valueOf(number), this.decimal, false, this.useCapital);
        toAppendTo.append(value);
        return toAppendTo;
    }
    
    @Override
    public StringBuffer format(final long number, final StringBuffer toAppendTo, final FieldPosition pos) {
        final String value = ChineseInt.parseToChinese(String.valueOf(number), false, this.useCapital);
        toAppendTo.append(value);
        return toAppendTo;
    }
    
    public static String toChineseDigitUnit(final double unitValue) {
        return toChineseDigitUnit((long)Math.rint(unitValue));
    }
    
    public static String toChineseDigitUnit(long unitValue) {
        int factor;
        for (factor = 0; unitValue >= 10L; unitValue /= 10L, ++factor) {}
        return (factor >= ChineseNumberFormat.chDigitUnits.length) ? null : ChineseNumberFormat.chDigitUnits[factor];
    }
}
